@@ -3,14 +3,14 @@
 #'
 #' @param x Vector of taxa names (character) or IDs (character or numeric) to
 #' query.
-#' @param db character; database to query. either `itis`, `tropicos`, `col`,
-#' `nbn`, `worms`. Note that each taxonomic data source has their own
+#' @param db character; database to query. either `itis`, `tropicos`,
+#' `nbn`, `worms`, or `pow`. Note that each taxonomic data source has their own
 #' identifiers, so that if you provide the wrong `db` value for the identifier
 #' you could get a result, but it will likely be wrong (not what you were
 #' expecting). If using tropicos, we  recommend getting an API key;
 #' see [taxize-authentication]
 #' @param id character; identifiers, returned by [get_tsn()], [get_tpsid()],
-#' [get_nbnid()], [get_colid()] `get_wormsid()]
+#' [get_nbnid()], [get_wormsid()], [get_pow()]
 #' @param rows (numeric) Any number from 1 to infinity. If the default NA, all
 #' rows are considered. Note that this parameter is ignored if you pass in a
 #' taxonomic id of any of the acceptable classes: tsn, tpsid, nbnid, ids.
@@ -18,12 +18,12 @@
 #' functions to gather synonyms.
 #'
 #' @return A named list of results with three types of output in each slot:
-#' 
-#' - if the name was not found: `NA_character_` 
+#'
+#' - if the name was not found: `NA_character_`
 #' - if the name was found but no synonyms found, an empty data.frame (0 rows)
 #' - if the name was found, and synonyms found, a data.frames with the
 #' synonyms - the column names vary by data source
-#' 
+#'
 #' @details If IDs are supplied directly (not from the `get_*()` functions)
 #' you must specify the type of ID.
 #'
@@ -34,8 +34,8 @@
 #' Note that IUCN requires an API key. See [rredlist::rredlist-package]
 #' for help on authentiating with IUCN Redlist
 #'
-#' @seealso [get_tsn()] `get_tpsid()], [get_nbnid()] `get_colid()],
-#' [get_wormsid()] `get_iucn()]
+#' @seealso [get_tsn()] [get_tpsid()] [get_nbnid()]
+#' [get_wormsid()] [get_iucn()] [get_pow()]
 #'
 #' @export
 #' @examples \dontrun{
@@ -43,9 +43,9 @@
 #' synonyms(183327, db="itis")
 #' synonyms("25509881", db="tropicos")
 #' synonyms("NBNSYS0000004629", db='nbn')
-#' # synonyms("87e986b0873f648711900866fa8abde7", db='col') # FIXME
 #' synonyms(105706, db='worms')
 #' synonyms(12392, db='iucn')
+#' synonyms('urn:lsid:ipni.org:names:358881-1', db='pow')
 #'
 #' # Plug in taxon names directly
 #' synonyms("Pinus contorta", db="itis")
@@ -55,11 +55,11 @@
 #' synonyms("Pinus contorta", db="tropicos")
 #' synonyms(c("Poa annua",'Pinus contorta'), db="tropicos")
 #' synonyms("Pinus sylvestris", db='nbn')
-#' synonyms("Puma concolor", db='col')
-#' synonyms("Ursus americanus", db='col')
-#' synonyms("Amblyomma rotundatum", db='col')
 #' synonyms('Pomatomus', db='worms')
 #' synonyms('Pomatomus saltatrix', db='worms')
+#' synonyms('Lithocarpus mindanaensis', db='pow')
+#' synonyms('Poa annua', db='pow')
+#' synonyms(c('Poa annua', 'Pinus contorta', 'foo bar'), db='pow')
 #'
 #' # not accepted names, with ITIS
 #' ## looks for whether the name given is an accepted name,
@@ -71,8 +71,8 @@
 #' synonyms(get_tsn("Poa annua"))
 #' synonyms(get_tpsid("Poa annua"))
 #' synonyms(get_nbnid("Carcharodon carcharias"))
-#' synonyms(get_colid("Ornithodoros lagophilus"))
 #' synonyms(get_iucn('Loxodonta africana'))
+#' synonyms(get_pow('Lithocarpus mindanaensis'))
 #'
 #' # Pass many ids from class "ids"
 #' out <- get_ids(names="Poa annua", db = c('itis','tropicos'))
@@ -82,13 +82,10 @@
 #' synonyms("Poa annua", db='tropicos', rows=1)
 #' synonyms("Poa annua", db='tropicos', rows=1:3)
 #' synonyms("Pinus sylvestris", db='nbn', rows=1:3)
-#' synonyms("Amblyomma rotundatum", db='col', rows=2)
-#' synonyms("Amblyomma rotundatum", db='col', rows=2:3)
 #'
 #' # Use curl options
 #' synonyms("Poa annua", db='tropicos', rows=1, verbose = TRUE)
 #' synonyms("Poa annua", db='itis', rows=1, verbose = TRUE)
-#' synonyms("Poa annua", db='col', rows=1, verbose = TRUE)
 #'
 #'
 #' # combine many outputs together
@@ -96,7 +93,6 @@
 #' synonyms_df(x)
 #'
 #' ## note here how Pinus contorta is dropped due to no synonyms found
-#' x <- synonyms(c("Poa annua",'Pinus contorta','Puma concolor'), db="col")
 #' synonyms_df(x)
 #'
 #' ## note here that ids are taxon identifiers b/c you start with them
@@ -134,11 +130,6 @@ synonyms.default <- function(x, db = NULL, rows = NA, ...) {
       structure(stats::setNames(synonyms(id, ...), x),
                 class = "synonyms", db = "nbn")
     },
-    col = {
-      id <- process_syn_ids(x, db, get_colid, rows = rows, ...)
-      structure(stats::setNames(synonyms(id, ...), x),
-                class = "synonyms", db = "col")
-    },
     worms = {
       id <- process_syn_ids(x, db, get_wormsid, rows = rows, ...)
       structure(stats::setNames(synonyms(id, ...), x),
@@ -149,23 +140,33 @@ synonyms.default <- function(x, db = NULL, rows = NA, ...) {
       structure(stats::setNames(synonyms(id, ...), x),
                 class = "synonyms", db = "iucn")
     },
+    pow = {
+      id <- process_syn_ids(x, db, get_pow, ...)
+      structure(stats::setNames(synonyms(id, ...), x),
+                class = "synonyms", db = "pow")
+    },
     stop("the provided db value was not recognised", call. = FALSE)
   )
 }
 
 process_syn_ids <- function(input, db, fxn, ...){
   g <- tryCatch(as.numeric(as.character(input)), warning = function(e) e)
+  if (inherits(g, "condition") && all(!grepl("ipni\\.org", input))) {
+    return(eval(fxn)(input, ...))
+  }
   if (
-    inherits(g,"numeric") || is.character(input) && grepl("N[HB]", input) ||
-      is.character(input) && grepl("[[:digit:]]", input)
+    is.numeric(g) ||
+    is.character(input) && all(grepl("N[HB]", input)) ||
+    is.character(input) && all(grepl("ipni\\.org", input)) ||
+    is.character(input) && all(grepl("[[:digit:]]", input))
   ) {
     as_fxn <- switch(db,
-                     itis = as.tsn,
-                     tropicos = as.tpsid,
-                     nbn = as.nbnid,
-                     col = as.colid,
-                     worms = as.wormsid,
-                     iucn = as.iucn)
+      itis = as.tsn,
+      tropicos = as.tpsid,
+      nbn = as.nbnid,
+      worms = as.wormsid,
+      iucn = as.iucn,
+      pow = as.pow)
     if (db == "iucn") return(as_fxn(input, check = TRUE))
     return(as_fxn(input, check = FALSE))
   } else {
@@ -176,6 +177,7 @@ process_syn_ids <- function(input, db, fxn, ...){
 #' @export
 #' @rdname synonyms
 synonyms.tsn <- function(id, ...) {
+  warn_db(list(...), "itis")
   fun <- function(x){
     if (is.na(x)) { NA_character_ } else {
       is_acc <- rit_acc_name(x, ...)
@@ -202,9 +204,6 @@ synonyms.tsn <- function(id, ...) {
           tmp <- stats::setNames(tmp, c('syn_author', 'syn_name', 'syn_tsn'))
           cbind(w, tmp, row.names = NULL)
         }
-        # if (as.character(tmp[1,1]) == 'nomatch') {
-        #   tmp <- data.frame(message = "no syns found", stringsAsFactors = FALSE)
-        # }
       }, x, split(accdf, seq_len(NROW(accdf))))
       do.call("rbind", unname(res))
     }
@@ -222,49 +221,10 @@ rit_acc_name <- function(x, ...) {
   }
 }
 
-#' @export
-#' @rdname synonyms
-synonyms.colid <- function(id, ...) {
-  fun <- function(x) {
-    if (is.na(x)) {
-      NA_character_
-    } else {
-      res <- col_synonyms(x, ...)
-      if (is.na(res)) tibble::tibble() else res
-    }
-  }
-  stats::setNames(lapply(id, fun), id)
-}
-
-col_synonyms <- function(x, ...) {
-  base <- "http://www.catalogueoflife.org/col/webservice"
-  args <- list(id = x[1], response = "full", format = "json")
-  cli <- crul::HttpClient$new(base, headers = tx_ual)
-  res <- cli$get(query = args)
-  res$raise_for_status()
-  out <- jsonlite::fromJSON(res$parse("UTF-8"), FALSE)
-  tmp <- out$results[[1]]
-  if ("synonyms" %in% names(tmp)) {
-    df <- taxize_ldfast(lapply(tmp$synonyms, function(w) {
-      w[sapply(w, length) == 0] <- NA
-      w$references <- NULL
-      data.frame(w, stringsAsFactors = FALSE)
-    }))
-    if (!is.null(df)) {
-      df$rank <- tolower(df$rank)
-    } else {
-      df <- NA
-    }
-
-    df
-  } else {
-    NULL
-  }
-}
-
 #' @export
 #' @rdname synonyms
 synonyms.tpsid <- function(id, ...) {
+  warn_db(list(...), "topicos")
   fun <- function(x) {
     if (is.na(x)) {
       NA_character_
@@ -279,6 +239,7 @@ synonyms.tpsid <- function(id, ...) {
 #' @export
 #' @rdname synonyms
 synonyms.nbnid <- function(id, ...) {
+  warn_db(list(...), "nbn")
   fun <- function(x){
     if (is.na(x)) {
       NA_character_
@@ -293,11 +254,12 @@ synonyms.nbnid <- function(id, ...) {
 #' @export
 #' @rdname synonyms
 synonyms.wormsid <- function(id, ...) {
+  warn_db(list(...), "worms")
   fun <- function(x) {
     if (is.na(x)) {
       NA_character_
     } else {
-      res <- tryCatch(worrms::wm_synonyms(as.numeric(x), ...), 
+      res <- tryCatch(worrms::wm_synonyms(as.numeric(x), ...),
         error = function(e) e)
       if (inherits(res, "error")) tibble::tibble() else res
     }
@@ -308,6 +270,7 @@ synonyms.wormsid <- function(id, ...) {
 #' @export
 #' @rdname synonyms
 synonyms.iucn <- function(id, ...) {
+  warn_db(list(...), "iucn")
   out <- vector(mode = "list", length = length(id))
   for (i in seq_along(id)) {
     if (is.na(id[[i]])) {
@@ -320,7 +283,26 @@ synonyms.iucn <- function(id, ...) {
   stats::setNames(out, id)
 }
 
-
+#' @export
+#' @rdname synonyms
+synonyms.pow <- function(id, ...) {
+  warn_db(list(...), "pow")
+  out <- vector(mode = "list", length = length(id))
+  for (i in seq_along(id)) {
+    if (is.na(id[[i]])) {
+      out[[i]] <- NA_character_
+    } else {
+      res <- pow_synonyms(id[i], ...)
+      out[[i]] <- if (length(res) == 0) {
+        tibble::tibble() 
+      } else {
+        names(res)[1] <- "id"
+        res
+      }
+    }
+  }
+  stats::setNames(out, id)
+}
 
 
 
@@ -353,7 +335,6 @@ synonyms_df.default <- function(x) {
 
 #' @export
 synonyms_df.synonyms <- function(x) {
-  # x <- Filter(function(z) inherits(z[1], "data.frame"), x)
   x <- Filter(function(z) inherits(z, "data.frame"), x)
   x <- Filter(function(z) NROW(z) > 0, x)
   (data.table::setDF(
