@@ -23,3 +23,12 @@ test_that("sci2comm returns the correct value", {
   expect_that(zz, is_a("list"))
   expect_that(zz[[1]], is_a("character"))
 })
+
+test_that("warn on mismatch 'db'", {
+  skip_on_cran()
+  vcr::use_cassette("sci2comm_warn_on_db_mismatch", {
+    expect_warning(
+      sci2comm(
+        get_tsn('Helianthus annuus', messages = FALSE), db = "ncbi"))
+  })
+})
